@@ -17,8 +17,12 @@
 #define PAYLOAD       0x10
 #define PTS_DTS_FLAGS 0xC0
 
-cFemonReceiver::cFemonReceiver(int Ca, int Vpid, int Apid[], int Dpid[])
+cFemonReceiver::cFemonReceiver(tChannelID ChannelID, int Ca, int Vpid, int Apid[], int Dpid[])
+#if defined(APIVERSNUM) && APIVERSNUM < 10500
 :cReceiver(Ca, -1, Vpid, Apid, Dpid, NULL), cThread("femon receiver")
+#else
+:cReceiver(ChannelID, -1, Vpid, Apid, Dpid, NULL), cThread("femon receiver")
+#endif
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   m_VideoPid = Vpid;
